# e-drone


* Install
```
> pip install e_drone
> pip --no-cache-dir install e_drone
```

* Upgrade
```
> pip install --upgrade e_drone
```

* Uninstall
```
> pip uninstall e_drone
```



## Link

* [PyPI E-Drone](https://pypi.org/project/e-drone/)
* [Documents for E-Drone python library.](https://byrobot.github.io/documents/kr/products/e_drone/library/python/e_drone/)
* [BYROBOT Dev](http://dev.byrobot.co.kr/)
* [BYROBOT Forum](https://groups.google.com/d/forum/byrobot)
* [Discord BYROBOT](https://discord.gg/UVVJMye)
* [Youtube BYROBOT Channel](https://www.youtube.com/user/BYROBOTCO)
* [Facebook BYROBOT](https://www.facebook.com/Byrobot.Drones)


### BYROBOT

